<?php
/**
 * Plugin Name:         EchoAI
 * Plugin URI:          https://echowp.com/
 * Description:         EchoAI for WordPress is an <strong>AI-driven chatbot</strong> plugin, leveraging OpenAI's advanced technology to provide intelligent and relevant responses to your website visitors. The plugin scans and indexes your published posts, enabling the AI assistant to interact with users based on your content. Perfect for any website looking to offer a cutting-edge, interactive experience.
 * Author:              EchoAI
 * Author URI:          https://echowp.com/contact
 * Text Domain:         echo-ai
 * Version:             0.1.2
 * Requires at least:   5.9
 * Requires PHP:        8.0
 * License:             GPLv2 or later
 * License URI:         https://www.gnu.org/licenses/gpl-2.0.html
 *
 *
 * @package         ECHOAI
 */

require 'lib/settings.php';
require 'lib/shortcode.php';
require 'lib/helpers.php';
require 'lib/api.php';
require 'lib/forms.php';
require 'lib/blocks.php';
require 'lib/floating-button.php';

defined('ABSPATH') || exit;

if (!defined('ECHOAI_SERVICE_URL')) {
    define('ECHOAI_SERVICE_URL', "https://api.echowp.com/");
}

define('ECHOAI_PLUGIN_URL', plugin_dir_url(__FILE__));
define('ECHOAI_PLUGIN_PATH', plugin_dir_path(__FILE__));
define('ECHOAI_API_HOST', rtrim(ECHOAI_SERVICE_URL, "/") . "/api");
define('ECHOAI_SETTINGS', admin_url() . 'admin.php?page=echoai');
define('ECHOAI_SETUP', admin_url() . 'admin.php?page=echoai_setup');
define('ECHOAI_LOGO', ECHOAI_PLUGIN_URL . 'images/logo.svg');
define('ECHOAI_ICON', ECHOAI_PLUGIN_URL . 'images/icon.svg');
define('ECHOAI_MENU_ICON', ECHOAI_PLUGIN_URL . 'images/menu-icon.svg');
define('ECHOAI_JSSDK', "https://cdn.echowp.com/echoai/echo-ai-latest.js");
define('ECHOAI_SETUP_VERSION', '1.0.7');

add_action('admin_init', function () {
    wp_register_style('echoaicss', plugins_url('stylesheet.css', __FILE__), false, ECHOAI_SETUP_VERSION);
    wp_register_style('echoaisetupcss', plugins_url('installer/dist/style.css', __FILE__), false, ECHOAI_SETUP_VERSION);
    wp_register_script('echoaisetupjs-installer', plugins_url('installer/dist/installer.js', __FILE__), false, ECHOAI_SETUP_VERSION, ['in_footer' => true]);
    wp_register_script('echoaisetupjs-mini', plugins_url('installer/dist/mini.js', __FILE__), false, ECHOAI_SETUP_VERSION, ['in_footer' => true]);
});

add_filter('wp_script_attributes', 'add_type_attribute', 10, 1);

function add_type_attribute($attributes)
{
    if (isset($attributes['id']) && ($attributes['id'] === 'echoaisetupjs-installer-js'
        || $attributes['id'] === 'echoaisetupjs-mini-js')) {
        $attributes['type'] = 'module';
    }

    return $attributes;
}

add_action('init', function () {
    wp_register_script('echoaisdk', ECHOAI_JSSDK, false, ECHOAI_SETUP_VERSION, ['in_footer' => true]);
});

register_deactivation_hook(__FILE__, function () {
    delete_option('echoai_partner');
    delete_option('echoai_hash');
    delete_option('echoai_assistant_image');
    delete_option('echoai_post_types');
    delete_option('echoai_floating_button');
    delete_option('echoai_index_finished');
    delete_option('echoai_wp_api_key');

    $demo_page_id = get_option('echoai_demo_page_id');
    if ($demo_page_id) {
        wp_delete_post($demo_page_id, true);
        delete_option('echoai_demo_page_id');
    }

});

register_activation_hook(__FILE__, function () {

    delete_option('echoai_partner');
    delete_option('echoai_hash');
    delete_option('echoai_assistant_image');
    delete_option('echoai_floating_button');
    delete_option('echoai_demo_page_id');
    delete_option('echoai_post_types');
    delete_option('echoai_index_finished');
    delete_option('echoai_wp_api_key');

    if (!get_option('echoai_assistant_image')) {
        add_option('echoai_assistant_image', ECHOAI_ICON);
    }

    if (!get_option('echoai_post_types')) {
        add_option('echoai_post_types', ["post", "page"]);
    }
    if (!get_option('echoai_floating_button')) {
        add_option('echoai_floating_button', "bottom_right");
    }

    if (!get_option('echoai_index_finished')) {
        add_option('echoai_index_finished', false);
    }

    if (!get_option('echoai_wp_api_key')) {
        // Generate a random key    
        $api_key = bin2hex(random_bytes(16));
        add_option('echoai_wp_api_key', $api_key);
    }


    $page_title = 'Echo AI Chat';
    $query = new WP_Query([
        'post_type' => 'page',
        'title' => $page_title,
        'posts_per_page' => 1
    ]);

    if ($query->have_posts()) {
        $query->the_post();
        $page = get_post();
        wp_reset_postdata();
    } else {
        $page = null;
    }

    if (!$page) {
        $new_page = [
            'post_title' => $page_title,
            'post_content' => '<!-- wp:echo-ai/chat /-->',
            'post_status' => 'publish',
            'post_author' => 1,
            'post_type' => 'page'
        ];
        $id = wp_insert_post($new_page);
        add_option('echoai_demo_page_id', $id);

    }

});
