<?php

function echoai_get_floating_button_position() {
    return get_option('echoai_floating_button', 'none');
}

function should_display_floating_button() {
    $is_index_finished = get_option('echoai_index_finished');
    $position = echoai_get_floating_button_position();
    return $is_index_finished && in_array($position, ['bottom_right', 'bottom_left', 'top_right', 'top_left']);
}

function echoai_add_floating_button() {
    if (!should_display_floating_button()) return;

    wp_enqueue_script('echoaisdk');
    $icon = esc_url(get_option('echoai_assistant_image'));
    echo '<button id="echoai_floatbutton" aria-label="AI Assistant"><img src="' . $icon . '" alt="AI Assistant"><span class="echoai_tooltip">AI Assistant</span></button>';
    echo '<div id="echoai_floatchat"></div>';
}
add_action('wp_footer', 'echoai_add_floating_button');

function echoai_add_floating_button_styles() {
    if (!should_display_floating_button()) return;
    $position = echoai_get_floating_button_position();
    ?>
    <style>
        #echoai_floatbutton {
            position: fixed;
            width: 40px;
            height: 40px;
            border: none;
            cursor: pointer;
            padding: 0;
            background: none;
            z-index: 9999;
            opacity: 0;
            transform: translateY(8px) scale(0.8);
            transition: opacity 0.1s ease, transform 0.1s ease;

            <?php
            switch ($position) {
                case 'bottom_left':
                    echo 'bottom: 20px; left: 20px;';
                    break;
                case 'top_right':
                    echo 'top: 20px; right: 20px;';
                    break;
                case 'top_left':
                    echo 'top: 20px; left: 20px;';
                    break;
                default: // bottom_right
                    echo 'bottom: 20px; right: 20px;';
            }
            ?>
        }
        #echoai_floatbutton.echoai-button-visible {
            opacity: 1;
            transform: translateY(0) scale(1);
        }
        #echoai_floatbutton img {
            width: 100%;
            height: 100%;
            object-fit: cover;
        }
        #echoai_floatchat {
            position: fixed;
            display: none;
            width: 350px;
            height: 500px;
            max-width: calc(100% - 30px);
            max-height: calc(100% - 90px);
            z-index: 99999;
            box-shadow: 0 0 15px 0 rgba(30, 30, 30, 0.08);
            border-radius: 16px;
            <?php
            switch ($position) {
                case 'bottom_left':
                    echo 'bottom: 80px; left: 20px;';
                    break;
                case 'top_right':
                    echo 'top: 80px; right: 20px;';
                    break;
                case 'top_left':
                    echo 'top: 80px; left: 20px;';
                    break;
                default: // bottom_right
                    echo 'bottom: 80px; right: 20px;';
            }
            ?>
        }
        .echoai_tooltip {
            visibility: hidden;
            width: auto;
            max-width: 200px;
            background-color: #555;
            color: #fff;
            text-align: center;
            border-radius: 6px;
            padding: 5px 10px;
            position: absolute;
            z-index: 1;
            opacity: 0;
            transition: opacity 0.3s;
            white-space: nowrap;
            <?php
            switch ($position) {
                case 'bottom_left':
                case 'top_left':
                    echo 'left: calc(100% + 10px); top: 50%; transform: translateY(-50%);';
                    break;
                default: // bottom_right and top_right
                    echo 'right: calc(100% + 10px); top: 50%; transform: translateY(-50%);';
            }
            ?>
        }
        .echoai_tooltip::after {
            content: "";
            position: absolute;
            top: 50%;
            margin-top: -5px;
            border-width: 5px;
            border-style: solid;
            <?php
            switch ($position) {
                case 'bottom_left':
                case 'top_left':
                    echo 'right: 100%; border-color: transparent #555 transparent transparent;';
                    break;
                default: // bottom_right and top_right
                    echo 'left: 100%; border-color: transparent transparent transparent #555;';
            }
            ?>
        }
        #echoai_floatbutton:hover .echoai_tooltip {
            visibility: visible;
            opacity: 1;
        }
        @media (max-width: 700px) {
            #echoai_floatbutton {
                width: 50px;
                height: 50px;
                <?php
                switch ($position) {
                    case 'bottom_left':
                        echo 'bottom: 10px; left: 10px;';
                        break;
                    case 'top_right':
                        echo 'top: 10px; right: 10px;';
                        break;
                    case 'top_left':
                        echo 'top: 10px; left: 10px;';
                        break;
                    default: // bottom_right
                        echo 'bottom: 10px; right: 10px;';
                }
                ?>
            }
            #echoai_floatchat {
                top: 15px;
                left: 15px;
                right: 15px;
                bottom: 15px;
                width: auto;
                height: auto;
            }
            .echoai_tooltip {
                display: none;
            }
        }
    </style>
    <?php
}
add_action('wp_head', 'echoai_add_floating_button_styles');

function echoai_add_floating_button_script() {
    if (!should_display_floating_button()) return;
    
    $partnercredentials = json_decode(get_option('echoai_partner'), true);
    $app_id = isset($partnercredentials['appId']) ? $partnercredentials["appId"] : null;
    $icon = esc_js(get_option('echoai_assistant_image'));
    ?>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const floatButton = document.getElementById('echoai_floatbutton');
            const chatContainer = document.getElementById('echoai_floatchat');

            floatButton.addEventListener('click', function(event) {
                event.stopPropagation();
                toggleChat();
            });

            setTimeout(() => {
                floatButton.classList.add('echoai-button-visible');
            }, 100); 


            document.addEventListener('click', function(event) {
                if (chatContainer.style.display === 'block' && !chatContainer.contains(event.target) && event.target !== floatButton) {
                    chatContainer.style.display = 'none';
                }
            });

            function toggleChat() {
                if (chatContainer.style.display === 'none' || chatContainer.style.display === '') {
                    chatContainer.style.display = 'block';
                    const isMobile = window.innerWidth <= 700;
                    const width = isMobile ? chatContainer.clientWidth : 350;
                    const height = isMobile ? chatContainer.clientHeight : 500;

                    setTimeout(() => {
                        initEchoChat({
                            containerId: "echoai_floatchat",
                            appId: "<?php echo $app_id ?>",
                            assistantImage: "<?php echo $icon ?>",
                            width: width + "px",
                            height: height + "px",
                            autoFocus: true,
                        });
                    }, 10);
                } else {
                    chatContainer.style.display = 'none';
                }
            }
        });
    </script>
    <?php
}
add_action('wp_footer', 'echoai_add_floating_button_script', 100);