<?php

function echoai_get_plans()
{

    $plans = echoai_call_service_api("plans", [], "GET");
    return $plans;

}

function echoai_get_available_post_types()
{

    $echoai_post_types = get_option('echoai_post_types') ?: [];

    $exlude = ["media", "attachment", "elementor_library", "wp_block", "revision", "nav_menu_item", "custom_css", "customize_changeset", "oembed_cache", "user_request", "wp_log", "user_request_action", "user_request_action_comment", "user_request_action_email", "user_request_exporter", "user_request_personal_data"];
    $post_types = get_post_types(['public' => true, 'show_in_rest' => true], 'objects');

    $available_post_types = [];
    foreach ($post_types as $post_type) {
        if (!in_array($post_type->name, $exlude)) {
            $type = [
                "label" => $post_type->label,
                "name" => $post_type->name,
                "enabled" => in_array($post_type->name, $echoai_post_types)
            ];
            array_push($available_post_types, $type);
        }
    }
    return $available_post_types;
}

function echoai_collect_all_posts()
{
    global $wpdb;

    $partner = echoai_call_service_api("partner", [], "GET");

    if (is_wp_error($partner)) {
        return $partner;
    }

    $user_plan = $partner["activePlan"];
    $limit = $partner["activePlan"]["limits"]["articles"]["value"] ?? 1;

    $echoai_post_types = get_option('echoai_post_types') ?: [];

    $cache_key_posts = 'query_results_posts_' . md5(implode(',', $echoai_post_types) . $limit);
    $cache_key_count = 'query_results_count_' . md5(implode(',', $echoai_post_types) . $limit);

    // Try to get cached results
    $posts = wp_cache_get($cache_key_posts);
    $count = wp_cache_get($cache_key_count);

    if ($posts === false || $count === false) {

        // phpcs:disable WordPress.DB.DirectDatabaseQuery.DirectQuery
        $posts = $wpdb->get_results($wpdb->prepare( //db call ok; no-cache ok
            "SELECT SQL_CALC_FOUND_ROWS CAST(ID as CHAR) as id, post_type as type
            FROM $wpdb->posts
            WHERE post_status = %s
            AND post_type IN (" . implode(',', array_fill(0, count($echoai_post_types), '%s')) . ")
            ORDER BY ID DESC
            LIMIT %d",
            array_merge(['publish'], $echoai_post_types, [$limit])
        ), ARRAY_A); //db call ok; no-cache ok

        $count = $wpdb->get_var("SELECT FOUND_ROWS()"); //db call ok; no-cache ok
        // phpcs:enable WordPress.DB.DirectDatabaseQuery.DirectQuery

        $types = [];
        foreach ($echoai_post_types as $type) {
            $post_type_object = get_post_type_object($type);

            if (!$post_type_object || $post_type_object->show_in_rest != 1) {
                continue; // Skip this post type
            }
            $rest_base = $post_type_object->rest_base ?: $post_type_object->name;
            $types[$type] = $rest_base;
        }

        foreach ($posts as $k => $post) {
            $posts[$k]['type'] = $types[$post['type']];
        }

        wp_cache_set($cache_key_posts, $posts, "echo1", 60 * 5);
        wp_cache_set($cache_key_count, $count, "echo1", 60 * 5);
    }

    return [
        "posts" => $posts,
        "count" => $count
    ];
}
