<?php

add_action('admin_menu', 'echoai_menu');

function echoai_menu()
{
    $page1 = add_menu_page('Echo AI', 'Echo AI', 'manage_options', 'echoai', 'echoai_main_page', ECHOAI_MENU_ICON);
    $page2 = add_submenu_page(
        'echoai',
        'Settings',
        'Settings',
        'manage_options',
        'echoai_settings',
        'echoai_settings_page'
    );
    add_action("admin_print_styles-{$page2}", function () {
        wp_enqueue_style('echoaicss');
    });

    $credentials = json_decode(get_option('echoai_partner'), true);

    if ($credentials) {
        $page3 = add_submenu_page(
            'echoai',
            'Setup',
            'Setup',
            'manage_options',
            'echoai_setup',
            'echoai_setup_page'
        );
        add_action("admin_print_styles-{$page3}", function () {
            wp_enqueue_style('echoaisetupcss');
            wp_enqueue_style('echoaicss');
            wp_enqueue_script('echoaisetupjs-installer');
        });
    }


}

function echoai_main_page()
{
    $credentials = json_decode(get_option('echoai_partner'), true);

    if (!$credentials) {
        wp_enqueue_style('echoaisetupcss');
        wp_enqueue_script('echoaisetupjs-installer');
        include ECHOAI_PLUGIN_PATH . 'src/templates/page-setup.php';
        return;
    }
    wp_enqueue_script('echoaisetupjs-mini');

    $partner = echoai_call_service_api("partner", [], "GET");

    if (!$partner) {
        include ECHOAI_PLUGIN_PATH . 'src/templates/page-network-error.php';
        return;
    }

    wp_enqueue_style('echoaicss');
    include ECHOAI_PLUGIN_PATH . 'src/templates/page-plan.php';
}

function echoai_settings_page()
{
    include ECHOAI_PLUGIN_PATH . 'src/templates/page-settings.php';
}

function echoai_setup_page()
{

    $partner = echoai_call_service_api("partner", [], "GET");

    if (!$partner) {
        wp_enqueue_style('echoaicss');

        include ECHOAI_PLUGIN_PATH . 'src/templates/page-network-error.php';
        return;
    }

    include ECHOAI_PLUGIN_PATH . 'src/templates/page-setup.php';
}

add_action('admin_init', function () {

    register_setting('echoai_settings_group', 'echoai_post_types', function ($input) {
        return array_map('sanitize_text_field', (array) $input);
    });

    register_setting('echoai_settings_group', 'echoai_floating_button', function ($input) {
        return sanitize_text_field($input);
    });

    register_setting('echoai_settings_group', 'echoai_assistant_image', function ($input) {
        if ($input == null) {
            return null;
        }

        return sanitize_url($input);
    });
});

add_action('updated_option', function ($option_name, $old_value, $option_value) {
    if ($option_name == 'echoai_post_types' && $old_value != $option_value) {

        update_option('echoai_index_finished', 0);

        $posts = echoai_collect_all_posts();

        echoai_call_service_api("wp-webhook/batch", [
            'posts' => $posts["posts"],
        ]);

        wp_redirect(ECHOAI_SETUP);

        exit();

    }
}, 10, 3);
