import { InspectorControls, useBlockProps } from '@wordpress/block-editor';
import {
  __experimentalNumberControl as NumberControl,
  PanelBody,
} from '@wordpress/components';
import logo from '../../../images/logo.svg';

const Edit = (props) => {
  const { attributes, setAttributes } = props;

  let height = attributes.height || '500';

  const innerStyle = {
    width: '100%',
  };

  const handleHeightChange = (newHeight) => {
    if (newHeight > 1000) newHeight = 1000;
    if (newHeight < 200) newHeight = 200;
    setAttributes({ height: newHeight });
  };

  const blockProps = useBlockProps({ style: { height: height + 'px' } });

  return (
    <div>
      <InspectorControls>
        <PanelBody title="Chat Settings">
          <NumberControl
            label="Height (px)"
            value={height}
            onChange={handleHeightChange}
            min={200}
            max={1000}
          />
        </PanelBody>
      </InspectorControls>
      <div {...blockProps}>
        <div className="flex flex-col items-center justify-center h-full bg-stone-200 rounded-3xl">
          <img src={logo} alt="chat" />
          <p className="text-stone-400 font-semibold">Assistant Placeholder</p>
          <p className="text-xs text-stone-500 text-center max-w-xs leading-relaxed px-2">
            You can resize this block by adjusting the height in the settings
            panel on the right.
          </p>
        </div>
      </div>
    </div>
  );
};
export default Edit;
