<?php

    $plans = echoai_get_plans();

    $partnercredentials = json_decode(get_option('echoai_partner'), true);
    $demo_page_id = get_option('echoai_demo_page_id');

    $demo_page_url = $demo_page_id ? get_permalink($demo_page_id) : null;

    $is_index_finished = get_option('echoai_index_finished');

    if($partner && $partner["activePlan"]) {
        
        $user_plan = $partner["activePlan"];
        $article_usage = $partner["resourceUsage"] ?? 0;
        $message_usage = $partner["usagePeriods"][0]["userMessages"] ?? 0;

        $article_limit = $partner["activePlan"]["limits"]["articles"] ?? ["value"=>1, "unit"=>"articles"];
        $message_limit = $partner["activePlan"]["limits"]["messages"] ?? ["value"=>1, "unit"=>"messages"];

        $article_percent = min(round($article_usage / $article_limit["value"] * 100),100);
        $message_percent = min(round($message_usage / $message_limit["value"] * 100),100);

    }
?>
<div class="wrap box-border">
    <h2><img class="mt-4" src="<?php echo esc_html(ECHOAI_LOGO); ?>" /></h2>
    <p class="flex gap-3">
        <a href="https://echowp.com" class="text-echo">echowp.com</a> 
    </p>
    <div class="w-full mx-auto flex gap-6">
    
        <div class="w-96 pr-6">
            <?php if($is_index_finished): ?>
                <?php
                include ECHOAI_PLUGIN_PATH . '/src/templates/ai-client-gutenberg.php';
                ?>
            <?php else: ?>

                <?php

                    $wp_rest_url = get_rest_url();
                    $host = ECHOAI_API_HOST;
                    $api_key = get_option('echoai_wp_api_key');

                ?>
                <script>
                var apiConfig = {
                    setup: '<?php echo esc_js($wp_rest_url);?>echo-ai/v1/setup',
                    processJob: '<?php echo esc_js($wp_rest_url);?>echo-ai/v1/process-job',
                    dashboard: '<?php echo esc_js(ECHOAI_SETTINGS);?>',
                    apiKey: '<?php echo esc_js($api_key);?>',
                };
                </script>
    
                <div class="bg-yellow-100 border-l-4 border-yellow-500 text-yellow-700 p-4" role="alert">
                    <p class="font-bold">Indexing in progress</p>
                    <div id="echoai_setup"></div>
                    <p class="text-sm">We are currently indexing your content. This can take time depending on the size of your website.</p>
                    <p class="text-sm">You can start using the assistant once the indexing is finished.</p>
                    <p>Check the progress in the <a href="<?php echo esc_html(admin_url() . 'admin.php?page=ECHOAI_connector_setup'); ?>" class="text-echo">setup page.</a></p>
                    <p>Need help? <a href="https://echowp.com" class="text-echo">Visit our website</a> or email us: <a href="mailto:info@echowp.com" class="text-echo">info@echowp.com</a> </p>
                </div>
            <?php endif;?>

        </div>
        <div class="grow py-4">
            <div class="w-full">
                <div class="max-w-lg">
                    <div class="flex gap-4">

                    <h3 class="mt-0 text-lg font-semibold"><span class="text-gray-400 font-normal">Your Plan:</span> <?php echo esc_html($user_plan["name"]); ?> 
                    </h3>
                    <?php if (!empty($partner["subscriptionId"])): ?>
                    <form method="post" action="<?php echo esc_html(admin_url( 'admin.php' )); ?>">
                        <?php wp_nonce_field('echo_manage_subscription', 'echo_manage_subscription_nonce'); ?>
                        <input type="hidden" name="subscriptionId" value="<?php echo esc_html($partner["subscriptionId"]); ?>">
                        <input type="submit" value="Manage subscription" class="cursor-pointer bg-echo text-white text-xs font-normal rounded-md border-0 px-2 py-1">
                    </form> 
                    <?php endif;?>
                    </div>
                
                    <div class="flex gap-4 items-end">
                        <span class="text-gray-600 w-36 text-base font-semibold">Articles</span>
                        <div class="w-full">
                            <span class="text-xs text-gray-400"><?php echo esc_html($article_usage); ?>/<?php echo esc_html($article_limit["value"]); ?></span>
                            <div class="w-full bg-gray-300 rounded-full h-4 dark:bg-gray-700">
                                <div class="bg-cyan-500 h-4 rounded-full" style="width: <?php echo esc_html($article_percent); ?>%"></div>
                            </div>
                        </div>
                    </div>

                    <div class="mt-4 flex gap-4 items-end">
                        <span class="text-gray-600 w-36 text-base font-semibold">Messages</span>
                        <div class="w-full">
                            <span class="text-xs text-gray-400"><?php echo esc_html($message_usage); ?>/<?php echo esc_html($message_limit["value"]); ?></span>
                            <div class="w-full bg-gray-300 rounded-full h-4 dark:bg-gray-700">
                                <div class="bg-cyan-500 h-4 rounded-full" style="width: <?php echo esc_html($message_percent); ?>%"></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="grid grid-cols-1 md:grid-cols-3 gap-4 max-w-3xl">
        <?php foreach ($plans as $plan):?>
        <?php 
                        $currentplan = ($plan["id"] == $user_plan["id"]);
                        $border_color = $currentplan ? "border-gray-600" : "border-gray-300";
                        $background_color = $currentplan ? "bg-gray-50" : "bg-gray-100";
                        $text_color = $currentplan ? "text-echo" : "text-gray-600";

                        $free = !$plan["price"];
        ?>
	            <div class="ring-offset-2 hover:ring ring-neutral-50 transition-all	<?php echo esc_html($background_color); ?> border <?php echo esc_html($border_color); ?> p-5 border-solid box-border mt-6 rounded-xl">
	                <p class="<?php echo esc_html($text_color);?> text-lg font-semibold text-center"><?php echo esc_html($plan["name"]); ?></p>
	                <p class="text-center">
	                <span class="p-1 bg-slate-800 text-gray-200 mt-2 font-bold rounded">
                    <?php if ($free): ?>
                        Free
                    <?php else: ?>
                        <?php echo esc_html($plan["price"]["amount"]); ?> <?php echo esc_html($plan["price"]["currency"]); ?>  / month
                    <?php endif;?>
	                </p>
	                <p class="text-center text-gray-400 mt-2"><?php echo esc_html($plan["description"]); ?></p>
	                <ul class="mt-4 mb-6">
	                    <?php foreach ($plan["limits"] as $limit): ?>
	                        <li><span class="font-bold text-gray-600"><?php echo esc_html($limit["value"]); ?></span> <?php echo esc_html($limit["unit"]); ?></li>
	                    <?php endforeach;?>
                </ul>
                <?php if (!$free): ?>
                    <?php if (!empty($partner["subscriptionId"])): ?>
                        <div class="text-center">
                            <form method="post" action="<?php echo esc_html(admin_url( 'admin.php' )); ?>">
                                <?php wp_nonce_field('echo_manage_subscription', 'echo_manage_subscription_nonce'); ?>
                                <input type="hidden" name="subscriptionId" value="<?php echo esc_html($partner["subscriptionId"]); ?>">
                                <input type="submit" value="Manage subscription" class="cursor-pointer bg-cyan-600 text-white text-md font-semibold rounded-md border-0 px-4 py-2 hover:bg-echo transition-all">
                            </form>
                        </div>
                    <?php else: ?>
                        <div class="text-center">
                            <form method="post" action="<?php echo esc_html(admin_url( 'admin.php' )); ?>">
                                <?php wp_nonce_field('echo_choose_plan', 'echo_choose_plan_nonce'); ?>
                                <input type="hidden" name="plan" value="<?php echo esc_html($plan["id"]); ?>">
                                <input type="submit" value="Choose plan" class="cursor-pointer bg-cyan-600 text-white text-md font-semibold rounded-md border-0 px-4 py-2 hover:bg-echo transition-all">
                            </form>
                        </div>
                    <?php endif;?>
                <?php endif;?>
            </div>
        <?php endforeach;?>
    </div>
        </div>
    
    </div>
      <?php if($demo_page_url): ?>
                <p>Test how your assistant looks like on your website: <a href="<?php echo esc_html($demo_page_url); ?>" class="text-echo"><?php echo esc_html($demo_page_url); ?></a></p>
            <?php endif;?>
            <p>Need help? <a href="https://echowp.com" class="text-echo">Visit our website</a> or email us: <a href="mailto:support@echowp.com" class="text-echo">support@echowp.com</a> </p>
</div>


    <div class="max-w-4xl mx-auto py-8 px-4 sm:px-6 lg:px-8">
   
</div>